@@ -12,7 +12,7 @@
 from functools import lru_cache, partialmethod
 import hashlib
 
-from simfin.load import load_shareprices, load_fundamental, load_companies
+from simfin.load import load_shareprices, load_fundamental, load_companies, load_derived_shareprices
 from simfin.paths import _path_dataset
 from simfin.rel_change import rel_change, mean_log_change
 from simfin.signals import price_signals, volume_signals, growth_signals
@@ -94,12 +94,15 @@ class StockHub:
         :param offset:
             Pandas DateOffset added to the date-index of the Pandas DataFrames
             with the fundamental data. Example: `pd.DateOffset(days=60)` This
-            is useful if you want to add a lag of e.g. 60 days to the dates of
-            financial reports with Income Statements, Balance Sheets, and
-            Cash-Flow Statements, because the REPORT_DATE is not when it was
-            actually made available to the public, which can be 1, 2 or even
-            3 months after the REPORT_DATE.
-            See :obj:`~simfin.utils.add_date_offset` for more details.
+            is useful if you are using `date_index=REPORT_DATE` and want to
+            add a lag of e.g. 60 days to the dates of financial reports with
+            Income Statements, Balance Sheets, and Cash-Flow Statements,
+            because the REPORT_DATE is not when it was actually made available
+            to the public, which can be 1, 2 or even 3 months after the
+            REPORT_DATE. See :obj:`~simfin.utils.add_date_offset` for more
+            details on how to set this parameter.
+            You can also use `date_index=PUBLISH_DATE` instead to get the first
+            date that the financial report was published.
 
         :param fill_method:
             String or callable for the method of filling in empty values when
@@ -235,6 +238,26 @@ class StockHub:
 
         return df
 
+    @lru_cache()
+    def load_derived_shareprices(self, variant):
+        """
+        Load dataset with share price ratios from the chosen market.
+
+        :param variant: String for either the 'daily' or 'latest' ratios.
+        :return: Pandas DataFrame
+        """
+
+        # Load the dataset.
+        df = load_derived_shareprices(variant=variant, market=self._market,
+                              index=[self._group_index, DATE],
+                              refresh_days=self._refresh_days_shareprices)
+
+        # Only use data for the given tickers?
+        if self._tickers is not None:
+            df = df.loc[self._tickers]
+
+        return df
+
     @lru_cache()
     def load_fundamental(self, dataset, variant):
         """
@@ -272,6 +295,10 @@ class StockHub:
     #: See :obj:`~simfin.hubs.StockHub.load_fundamental` for valid args.
     load_cashflow = partialmethod(load_fundamental, dataset='cashflow')
 
+    #: Load derived figures for the chosen market.
+    #: See :obj:`~simfin.hubs.StockHub.load_fundamental` for valid args.
+    load_derived = partialmethod(load_fundamental, dataset='derived')
+
     @lru_cache()
     def returns(self, name=None, future=True, annualized=False,
                 bdays=0, days=0, weeks=0, months=0, quarters=0, years=0):
